COMCTL32: Fix InitCommonControlsEx prototype

Thomas Weidenmueller wine-patches at reactsoft.com
Fri Jan 19 05:11:39 CST 2007


InitCommonControlsEx should use a pointer to constant data.

-------------- next part --------------
Index: include/commctrl.h
===================================================================
RCS file: /home/wine/wine/include/commctrl.h,v
retrieving revision 1.165
diff -u -r1.165 commctrl.h
--- include/commctrl.h	9 Jan 2007 12:11:36 -0000	1.165
+++ include/commctrl.h	19 Jan 2007 00:31:53 -0000
@@ -36,7 +36,7 @@
     DWORD dwICC;
 } INITCOMMONCONTROLSEX, *LPINITCOMMONCONTROLSEX;
 
-BOOL WINAPI InitCommonControlsEx (LPINITCOMMONCONTROLSEX);
+BOOL WINAPI InitCommonControlsEx (const INITCOMMONCONTROLSEX*);
 
 LANGID WINAPI GetMUILanguage (VOID);
 VOID WINAPI InitMUILanguage (LANGID uiLang);


More information about the wine-patches mailing list
Index: dlls/comctl32/commctrl.c
===================================================================
RCS file: /home/wine/wine/dlls/comctl32/commctrl.c,v
retrieving revision 1.102
diff -u -r1.102 commctrl.c
--- dlls/comctl32/commctrl.c	25 Oct 2006 18:31:19 -0000	1.102
+++ dlls/comctl32/commctrl.c	19 Jan 2007 00:31:34 -0000
@@ -610,7 +610,7 @@
  * Registers the common controls.
  *
  * PARAMS
  *     lpInitCtrls [I] pointer to an INITCOMMONCONTROLS structure.
  *
  * RETURNS
  *     Success: TRUE
@@ -627,24 +627,24 @@
  */
 
 BOOL WINAPI
-InitCommonControlsEx (LPINITCOMMONCONTROLSEX lpInitCtrls)
+InitCommonControlsEx (const INITCOMMONCONTROLSEX *picce)
 {
     INT cCount;
     DWORD dwMask;
 
-    if (!lpInitCtrls)
+    if (!picce)
 	return FALSE;
-    if (lpInitCtrls->dwSize != sizeof(INITCOMMONCONTROLSEX))
+    if (picce->dwSize != sizeof(INITCOMMONCONTROLSEX))
 	return FALSE;
 
-    TRACE("(0x%08x)\n", lpInitCtrls->dwICC);
+    TRACE("(0x%08x)\n", picce->dwICC);
 
     for (cCount = 0; cCount < 32; cCount++) {
 	dwMask = 1 << cCount;
-	if (!(lpInitCtrls->dwICC & dwMask))
+	if (!(picce->dwICC & dwMask))
 	    continue;
 
-	switch (lpInitCtrls->dwICC & dwMask) {
+	switch (picce->dwICC & dwMask) {
 	    /* dummy initialization */
 	    case ICC_ANIMATE_CLASS:
 	    case ICC_BAR_CLASSES:
@@ -610,7 +610,7 @@
  *
  * PARAMS
- *     lpInitCtrls [I] pointer to an INITCOMMONCONTROLS structure.
+ *     picce [I] pointer to an INITCOMMONCONTROLS structure.
  *
  * RETURNS